Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(524)

Unified Diff: lib/core/stopwatch.dart

Issue 11265024: Make methods in Stopwatch getters and rename to be more consistent. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Update status files with co19 issue number. Created 8 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « lib/compiler/samples/leap/leap_leg.dart ('k') | lib/coreimpl/stopwatch_implementation.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: lib/core/stopwatch.dart
diff --git a/lib/core/stopwatch.dart b/lib/core/stopwatch.dart
index e43f52d4bac7ced5274815a6b56b7d3910e81456..2cb77a7e4bf2c96a19f7c7be3846668344a7266d 100644
--- a/lib/core/stopwatch.dart
+++ b/lib/core/stopwatch.dart
@@ -45,21 +45,20 @@ abstract class Stopwatch {
* Returns 0 if the [Stopwatch] has never been started.
* The elapsed number of clock ticks increases by [frequency] every second.
*/
- int elapsed();
+ int get elapsedTicks;
/**
* Returns the [elapsed] counter converted to microseconds.
*/
- int elapsedInUs();
+ int get elapsedMicroseconds;
/**
* Returns the [elapsed] counter converted to milliseconds.
*/
- int elapsedInMs();
+ int get elapsedMilliseconds;
/**
* Returns the frequency of the elapsed counter in Hz.
*/
- int frequency();
-
+ int get frequency;
}
« no previous file with comments | « lib/compiler/samples/leap/leap_leg.dart ('k') | lib/coreimpl/stopwatch_implementation.dart » ('j') | no next file with comments »
@@ -45,21 +45,20 @@ abstract class Stopwatch {
/**
- * Returns the [elapsed] counter converted to microseconds.
+ * Returns the [elapsedTicks] counter converted to microseconds.
*/
@@ -45,21 +45,20 @@ abstract class Stopwatch {
/**
- * Returns the [elapsed] counter converted to milliseconds.
+ * Returns the [elapsedTicks] counter converted to milliseconds.
*/

Powered by Google App Engine
This is Rietveld 408576698